@@ -6,9 +6,9 @@ use Kavorka -all;
 use utf8;
 
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
-# V[m] | CH | {CH}C[v][m] | D | F | Hpv | W | Sid | N | Other
+# V[m] | CH | {CH}C[v][m] | D | F | Hpv | W | Sid | N | Other | NT
 
 # []  - 0 or 1 times
 # {}  - zero or more times
@@ -40,7 +40,7 @@ method TE::String::X() {
 }
 
 method TE::Tgc::X() {
-  ($self->{S} || $self->{Vm} || $self->{CH} || $self->{CHCvm} || $self->{D} || $self->{F} || $self->{Hpv} || $self->{W} ||  $self->{Sid} || $self->{N} || $self->{Other})->X();
+  ($self->{S} || $self->{Vm} || $self->{CH} || $self->{CHCvm} || $self->{D} || $self->{F} || $self->{Hpv} || $self->{W} ||  $self->{Sid} || $self->{N} || $self->{Other} || $self->{NT})->X() ;
 }
 
 method TE::S::X() {
@@ -88,11 +88,15 @@ method TE::Other::X() {
 }
 
 
+method TE::NT::X() {
+  push @result, $self->{''};
+}
+
 my $parser = qr {
     <nocontext:>
     <String>
     <objrule:  TE::String>        <[Tgc]>+
-    <objrule:  TE::Tgc>           <ws: (\s++)*> <S> | <Vm> | <CH> | <CHCvm> | <D> | <F> | <Hpv> | <W> | <Sid> | <N> | <Other>
+    <objrule:  TE::Tgc>           <ws: (\s++)*> <S> | <Vm> | <CH> | <CHCvm> | <D> | <F> | <Hpv> | <W> | <Sid> | <N> | <Other> | <NT>
     <objrule:  TE::Vm>            <V><m_>
     <objrule:  TE::CHCvm>         <CH__><C><v_><m_>
     <objtoken: TE::CH>            ([క-హ])( ్\b )
@@ -108,7 +112,8 @@ my $parser = qr {
     <objtoken: TE::Sid>           [౷]
     <objtoken: TE::N>             [ా-ౌ ౢ ౣ ఀ-ఄ ఽ ౕ ౖ]
     <objtoken: TE::S>             [ ]
-    <objtoken: TE::Other>         [^ఀ-౿]
+    <objtoken: TE::Other>         [ఀ-౿]
+    <objtoken: TE::NT>            [^ఀ-౿]
 }xms;
 
 
